# eric7.Graphics.UMLSceneSizeDialog

Module implementing a dialog to set the scene sizes.

### Global Attributes

None

### Classes

UMLSceneSizeDialog | Class implementing a dialog to set the scene sizes.

### Functions

None

## UMLSceneSizeDialog

Class implementing a dialog to set the scene sizes.

### Derived from

QDialog, Ui_UMLSceneSizeDialog

### Class Attributes

None

### Class Methods

None

### Methods

UMLSceneSizeDialog | Constructor
getData | Public method to retrieve the entered data.

### Static Methods

None

#### UMLSceneSizeDialog (Constructor)

UMLSceneSizeDialog(w, h, minW, minH, parent=None, name=None)

Constructor

w (int)
  current width of scene
h (int)
  current height of scene
minW (int)
  minimum width allowed
minH (int)
  minimum height allowed
parent (QWidget)
  parent widget of this dialog
name (str)
  name of this widget

#### UMLSceneSizeDialog.getData

getData()

Public method to retrieve the entered data.

Return:
  tuple giving the selected width and height

Return Type:
  tuple of (int, int)

Up